#!/bin/bash --login
#
# Editing this script should not be required.
#
# To specify an alternative Java Runtime Environment, set the environment
# variable SMARTSVN_JAVA_HOME or add a
#
# jre=/path/to/jre
#
# line to smartsvn.vmoptions (see below).
#
# To specify additional VM options, add them to smartsvn.vmoptions files.

parseVmOptions() {
  if [ -f $1 ]; then
    while read LINE || [[ -n "$LINE" ]]; do
      LINE="${LINE#"${LINE%%[![:space:]]*}"}"
      if [ ${#LINE} -gt 0 ] && [ ! ${LINE:0:1} == '#' ]; then
        if [ ${LINE:0:4} == 'jre=' ]; then
          SMARTSVN_JAVA_HOME="${LINE:4}"
        else
          _VM_PROPERTIES="$_VM_PROPERTIES $LINE"
        fi
      fi
    done < $1
  fi
}

echoJreConfigurationAndExit() {
    mkdir --parents ~/.smartsvn
    touch $SMARTSVN_CONFIG_DIR/smartsvn.vmoptions
    echo "Add the line"
    echo "jre=/path/to/jre"
    echo "to $SMARTSVN_CONFIG_DIR/smartsvn.vmoptions and change the path"
    echo "to the one pointing to the desired JRE."
    exit 1
}

case "$BASH" in
    */bash) :
        ;;
    *)
        exec /bin/bash "$0" "$@"
        ;;
esac


# check system architecture
ARCHITECTURE=`uname -m`
if [ "$ARCHITECTURE" != "x86_64" ] && [ "$ARCHITECTURE" != "aarch64" ] ; then
    echo "SmartGit is not supported any more on 32-bit systems."
    exit 1
fi

# Resolve the location of the SmartSVN installation.
# This includes resolving any symlinks.
PRG=$0
while [ -h "$PRG" ]; do
  ls=`ls -ld "$PRG"`
  link=`expr "$ls" : '^.*-> \(.*\)$' 2>/dev/null`
  if expr "$link" : '^/' 2> /dev/null >/dev/null; then
    PRG="$link"
  else
    PRG="`dirname "$PRG"`/$link"
  fi
done

SMARTSVN_BIN=`dirname "$PRG"`

# Absolutize dir
oldpwd=`pwd`
cd "${SMARTSVN_BIN}";
SMARTSVN_BIN=`pwd`
cd "${oldpwd}";
unset oldpwd

SMARTSVN_HOME=`dirname "$SMARTSVN_BIN"`

SMARTSVN_CONFIG_DIR=${XDG_CONFIG_HOME:-$HOME/.config}/smartsvn

parseVmOptions $SMARTSVN_BIN/smartsvn.vmoptions
parseVmOptions ~/.smartsvn/smartsvn.vmoptions
parseVmOptions $SMARTSVN_CONFIG_DIR/smartsvn.vmoptions

# Determine Java Runtime
if [ "$SMARTSVN_JAVA_HOME" = "" ] ; then
	SMARTSVN_JAVA_HOME=$SMARTSVNHG_JAVA_HOME
fi
if [ "$SMARTSVN_JAVA_HOME" = "" ] ; then
	SMARTSVN_JAVA_HOME=$JAVA_HOME
fi

_JAVA_EXEC="java"
if [ "$SMARTSVN_JAVA_HOME" != "" ] ; then
    _TMP="$SMARTSVN_JAVA_HOME/bin/java"
    if [ -f "$_TMP" ] ; then
        if [ -x "$_TMP" ] ; then
            _JAVA_EXEC="$_TMP"
        else
            echo "Warning: $_TMP is not executable"
        fi
    else
        echo "Warning: $_TMP does not exist"
    fi
elif [ -e "$SMARTSVN_HOME/jre/bin/java" ] && [ "$ARCHITECTURE" == "x86_64" ] ; then
    _JAVA_EXEC="$SMARTSVN_HOME/jre/bin/java"
fi

if ! which "$_JAVA_EXEC" >/dev/null 2>&1 ; then
    echo "Error: No Java Runtime Environment (JRE) 1.8 or higher found"
    echoJreConfigurationAndExit
fi

if type "lsb_release" > /dev/null 2> /dev/null ; then
    if [ "$XDG_CURRENT_DESKTOP" == "Unity" ] ; then
        # work-around for https://bugs.eclipse.org/bugs/show_bug.cgi?id=419729
        # work-around for https://bugs.eclipse.org/bugs/show_bug.cgi?id=502056
        export UBUNTU_MENUPROXY=0

        # Without the following line sliders are not visible in Ubuntu 12.04
        # (see <https://bugs.eclipse.org/bugs/show_bug.cgi?id=368929>)
        export LIBOVERLAY_SCROLLBAR=0
    fi
fi

if [ "$KDE_SESSION_UID" != "" ] && [ "$GTK2_RC_FILES" == "" ] ; then
	if grep -q "oxygen-gtk" "$HOME/.gtkrc-2.0-kde4"; then
		echo "Please change the GTK+ theme to something else than oxygen-gtk."
		echo "See also http://www.syntevo.com/blog/?p=4143"
		exit -1
	fi
fi

if [ "$XDG_SESSION_TYPE" = "wayland" ]; then
    export GDK_BACKEND=x11
fi

# work-around for https://bugs.eclipse.org/bugs/show_bug.cgi?id=542675
if [ "$GTK_IM_MODULE" == "xim" ] ; then
	export GTK_IM_MODULE=ibus
fi

#export SWT_GTK3=0
if [ "$SWT_GTK3" != "0" ] ; then
	echo "If you experience strange GUI bugs or crashes, set SWT_GTK3=0."
fi

#export GTK_THEME=Adwaita

_GC_OPTS="-XX:+UseG1GC -XX:MaxGCPauseMillis=100 -XX:InitiatingHeapOccupancyPercent=25 -Xmx1024m -Xss2m"
_MISC_OPTS="-Xverify:none -XX:MaxJavaStackTraceDepth=1000000 -Dsun.io.useCanonCaches=false"

# detect SmartSVN environment
_SMARTSVN_ENVIRONMENT=$("$_JAVA_EXEC" $_GC_OPTS $_MISC_OPTS $_VM_PROPERTIES -jar "$SMARTSVN_HOME/lib/bootloader.jar" -dump-environment)
_SUBVERSION_LIBRARY_PATH=$(echo "$_SMARTSVN_ENVIRONMENT" | grep subversion.binary.path | cut -d: -f2-)
_USER_PREFERENCES_PATH=$(echo "$_SMARTSVN_ENVIRONMENT" | grep user.preferences.path | cut -d: -f2-)
_SYSTEM_JRE_PATH=$(echo "$_SMARTSVN_ENVIRONMENT" | grep java.home | cut -d: -f2-)

# fatal JVM error log file
_VM_PROPERTIES="${_VM_PROPERTIES} -XX:ErrorFile=$SMARTSVN_CONFIG_DIR/hs_err_pid%p.log"

# pickup proper SASL2 libraries
export SASL_PATH="$_SUBVERSION_LIBRARY_PATH/sasl2"

# setup dynamic loader path to pickup proper subversion client libraries
# if enabled, this might cause problems on some systems, e.g. Fedora 26, for loading SWT
#export LD_LIBRARY_PATH=${_SUBVERSION_LIBRARY_PATH}:${LD_LIBRARY_PATH}

"$_JAVA_EXEC" $_GC_OPTS $_MISC_OPTS $_VM_PROPERTIES -jar "$SMARTSVN_HOME/lib/bootloader.jar" "$@"

